@@ -7,7 +7,8 @@ from ..settings import (
     JWT_REFRESH_TOKEN_EXPIRATION_DELTA,
     JWT_EXPIRATION_DELTA,
     UPDATE_USER_LAST_LOGIN_ON_AUTH,
-    UPDATE_USER_LAST_LOGIN_ON_REFRESH
+    UPDATE_USER_LAST_LOGIN_ON_REFRESH,
+    ENABLE_FINGERPRINTING
 )
 from ..utils import generate_refresh_token, generate_token_from_claims, decode_payload_from_token
 from ..utils.cookie import set_cookie, delete_cookie
@@ -23,15 +24,19 @@ def generate_refresh_token_cookie_data_from_userID(userID: str, request) -> obje
     rt = generate_refresh_token(userID=userID, request=request)
     update_user_last_login(rt.user, isLogin=True)
 
-    fingerprint = generate_fingerprint_from_request(request)
-    decoded = decode_fingerprint(fingerprint)
+    claims = {
+        'refreshToken': rt.get_token(),
+    }
+
+    if ENABLE_FINGERPRINTING:
+        fingerprint = generate_fingerprint_from_request(request)
+        decoded = decode_fingerprint(fingerprint)
+        claims['fingerprint'] = fingerprint
+        claims['ip'] = decoded['ip']
+        claims['userAgent'] = decoded['agent']
+
     return generate_token_from_claims(
-        claims={
-            'refreshToken': rt.get_token(),
-            'fingerprint': fingerprint,
-            'ip': decoded['ip'],
-            'userAgent': decoded['agent']
-        },
+        claims=claims,
         expirationDelta=JWT_REFRESH_TOKEN_EXPIRATION_DELTA
     )
 
@@ -158,39 +163,40 @@ def respond_handling_authentication(
             rt = verify_refresh_token(refreshToken)
 
             # Generate fingerprint for current request
-            fingerprint = generate_fingerprint_from_request(request)
-            decoded = decode_fingerprint(fingerprint)
+            if ENABLE_FINGERPRINTING:
+                fingerprint = generate_fingerprint_from_request(request)
+                decoded = decode_fingerprint(fingerprint)
 
-            # Check if fingerprint has changed due to IP or agent
-            # If changed, issue a new refresh token invalidating the old one
-            if (
-                rt.userAgent != decoded['agent']  # User Agent has changed
-                or rt.ip != decoded['ip']  # IP has changed
-            ):
-                # Revoke the old token
-                rt.revoked = timezone.now()
-                rt.save()
+                # Check if fingerprint has changed due to IP or agent
+                # If changed, issue a new refresh token invalidating the old one
+                if (
+                    rt.userAgent != decoded['agent']  # User Agent has changed
+                    or rt.ip != decoded['ip']  # IP has changed
+                ):
+                    # Revoke the old token
+                    rt.revoked = timezone.now()
+                    rt.save()
 
-                # Issue new refresh token
-                newToken = RefreshToken.objects.create(
-                    user=rt.user,
-                    ip=decoded['ip'],
-                    userAgent=decoded['agent']
-                )
-                data = generate_token_from_claims(
-                    claims={
-                        'refreshToken': newToken.get_token(),
-                        'fingerprint': fingerprint,
-                        'ip': decoded['ip'],
-                        'userAgent': decoded['agent']
-                    },
-                    expirationDelta=JWT_REFRESH_TOKEN_EXPIRATION_DELTA
-                )
-                refreshExpiresIn = data['payload']['exp']
-                resp = set_cookie(
-                    key='JWT_REFRESH_TOKEN', value=data['token'],
-                    expires=refreshExpiresIn, response=resp
-                )
+                    # Issue new refresh token
+                    newToken = RefreshToken.objects.create(
+                        user=rt.user,
+                        ip=decoded['ip'],
+                        userAgent=decoded['agent']
+                    )
+                    data = generate_token_from_claims(
+                        claims={
+                            'refreshToken': newToken.get_token(),
+                            'fingerprint': fingerprint,
+                            'ip': decoded['ip'],
+                            'userAgent': decoded['agent']
+                        },
+                        expirationDelta=JWT_REFRESH_TOKEN_EXPIRATION_DELTA
+                    )
+                    refreshExpiresIn = data['payload']['exp']
+                    resp = set_cookie(
+                        key='JWT_REFRESH_TOKEN', value=data['token'],
+                        expires=refreshExpiresIn, response=resp
+                    )
 
             update_user_last_login(rt.user, isRefresh=True)
 
