@@ -1,11 +1,12 @@
 from .view import *
 
-from .schema import AuthQueries, AuthMutations, SocialAuthMutations
+from .schema import AuthQueries, AuthMutations, RefreshTokenMutations, SocialAuthMutations
 
 
 __all__ = [
     'AuthQueries',
     'AuthMutations',
+    'RefreshTokenMutations',
     'SocialAuthMutations',
     'GraphQLView',
 ]
